Community
*********

:mod:`zope.pytest` was initially inventend and implemented by Martijn
Faassen.

.. _`mailing_list`:

Mailing List
============

Please contact the developers on the Zope-dev mailing list:
zope-dev@zope.org.

You can subscribe here:
https://mail.zope.org/mailman/listinfo/zope-dev

IRC
===

Come to the #bluebream IRC channel on FreeNode_.

.. _FreeNode: http://freenode.net/
